@@ -1,9 +1,10 @@
 describe.exp<-function(){
-category <- "censored"
+category <- "bounded"
 description  <- "Exponential Regression for Duration Dependent Variables"
+authors <- c()
+year <- 2007
 package <-list(	name 	="survival",
-		version	="2.0",
-		CRAN    =NA
+		version	="2.0"
 		)
 parameters<-list(mu="mu")
 parameters$mu<-list(equations=c(1,1),
@@ -13,5 +14,5 @@ parameters$mu<-list(equations=c(1,1),
 			specialFunction="Surv",
 			varInSpecialFunction=c(2,2))
 			
-list(category=category,description=description,package=package,parameters=parameters)
+list(category = category, authors = authors, year = year,description=description,package=package,parameters=parameters)
 }
