@@ -1,6 +1,8 @@
 describe.mlogit.bayes<-function(){
 category <- "multinomial"
 description  <- "Bayesian Multinomial Logistic Regression for Dependent Variables with Unordered Categorical Values"
+authors <- c("Ben Goodrich", "Ying Lu")
+year <- 2007
 package <-list(	name 	="MCMCpack",
 		version	="0.6"
 		)
@@ -13,5 +15,5 @@ parameters$mu<-list(equations=c(1,1),
 			varInSpecialFunction=c(1,1)
 		)
 			
-list(category=category,description=description,package=package,parameters=parameters)
+list(category = category, authors = authors, year = year,description=description,package=package,parameters=parameters)
 }
