@@ -1,6 +1,9 @@
 describe.probit<-function(){
 category <- "dichotomous"
 description  <- "Probit Regression for Dichotomous Dependent Variables"
+authors <- c()
+year <- 2007
+
 package <-list(	name 	="stats",
 		version	="0.1"
 		)
@@ -11,5 +14,5 @@ parameters$mu<-list(equations=c(1,1),
 			expVar=TRUE
 			)
 			
-list(category=category,description=description,package=package,parameters=parameters)
+list(category = category, authors = authors, year = year,description=description,package=package,parameters=parameters)
 }
