@@ -1,8 +1,8 @@
 qi.lm <- function(object, simpar, x, x1 = NULL, y = NULL) {
 
   k <- length(getcoef(object))
-  coef <- simpar[,1:k]
-  alpha <- simpar[,(k+1):ncol(simpar)]
+  coef <- simpar[,1:k,drop = FALSE]
+  alpha <- simpar[,ncol(simpar)]
   if (k < ncol(x))
     x <- as.data.frame(x[,names(coef(object)),drop = FALSE])
   ev <- coef %*% t(x)
@@ -18,6 +18,8 @@ qi.lm <- function(object, simpar, x, x1 = NULL, y = NULL) {
   }
   if (!is.null(y)) {
     yvar <- matrix(rep(y, nrow(simpar)), nrow = nrow(simpar), byrow = TRUE)
+#    tmp.ev <- qi$tt.ev <- yvar - qi$ev
+#    qi.name$tt.ev <- "Unit Treatment Effect for the Treated: Y - EV"
     tmp.ev <- yvar - qi$ev
     qi$att.ev <- matrix(apply(tmp.ev, 1, mean), nrow = nrow(simpar))
     qi.name$att.ev <- "Average Treatment Effect for the Treated: Y - EV"
